@@ -50,6 +50,7 @@
 #define UVM_PMA_ALLOCATE_FORCE_ALIGNMENT        NVBIT(9)
 #define UVM_PMA_ALLOCATE_NO_ZERO                NVBIT(10)
 #define UVM_PMA_ALLOCATE_TURN_BLACKLIST_OFF     NVBIT(11)
+#define UVM_PMA_ALLOCATE_ALLOW_PARTIAL          NVBIT(12)
 
 // Output flags
 #define UVM_PMA_ALLOCATE_RESULT_IS_ZERO         NVBIT(0)
@@ -489,7 +490,8 @@ typedef struct UvmPmaAllocationOptions_tag
     NvU32 minimumSpeed;         // valid if flags & UVM_PMA_ALLOCATE_SPECIFY_MININUM_SPEED
     NvU64 physBegin, physEnd;   // valid if flags & UVM_PMA_ALLOCATE_SPECIFY_ADDRESS_RANGE
     NvU32 regionId;             // valid if flags & UVM_PMA_ALLOCATE_SPECIFY_REGION_ID
-    NvU64 alignment;            // valid if flags & PMA_ALLOCATE_FORCE_ALIGNMENT
+    NvU64 alignment;            // valid if flags & UVM_PMA_ALLOCATE_FORCE_ALIGNMENT
+    NvLength numPagesAllocated; // valid if flags & UVM_PMA_ALLOCATE_ALLOW_PARTIAL
 
     NvU32 resultFlags;          // valid if the allocation function returns NV_OK
 } UvmPmaAllocationOptions;
